==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/he.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "פעילויות",
    "An error occurred while loading activities" : "אירעה שגיאה בעת טעינת הפעילויות",
    "No activity yet" : "אין עדיין פעילויות",
    "Load more activities" : "טעינת פעילויות נוספות",
    "Copied!" : "הועתק!",
    "Not supported!" : "לא נתמך!",
    "Press ⌘-C to copy." : "יש ללחוץ על ‎⌘+C כדי להעתיק.",
    "Press Ctrl-C to copy." : "יש ללחוץ על Ctrl+C כדי להעתיק.",
    "Home" : "בית",
    "{name} (invisible)" : "{name} (בלתי נראה)",
    "{name} (restricted)" : "{name} (מוגבל)",
    "in {path}" : "ב{path}",
    "This stream will show events like additions, changes & shares" : "הזרמת מידע זו מראה אירועים כגון תוספות, שינויים ושיתופים",
    "There are no events for this filter" : "אין אירועים לסינון זה",
    "Today" : "היום",
    "Yesterday" : "אתמול",
    "Open file" : "פתיחת קובץ",
    "Personal activity feed for %s" : "הזנת פעילות עצמית עבור %s",
    "Your feed URL is invalid" : "כתובת ההזנה שגויה",
    "Your settings have been updated." : "ההגדרות שלך עודכנו",
    "Settings have been updated." : "ההגדרות עודכנו",
    "All activities" : "כל הפעילויות",
    "By others" : "על ידי אחרים",
    "By you" : "על ידך",
    "\"remote user\"" : "\"משתמש מרוחק\"",
    "Activity notification for %s" : "התרעת פעילות עבור %s",
    "Hello %s" : "שלום %s",
    "Hello %s," : "שלום %s,",
    "There was some activity at %s" : "הייתה פעילות ב%s",
    "_and %n more _::_and %n more _" : ["ו־%n נוסף","ו־%n נוספים"],
    ", " : ",",
    "%s and %s" : "%s ו- %s",
    "Mail" : "דואר",
    "Stream" : "הזרמת מידע",
    "Activity" : "פעילות",
    "Activity feed" : "דיווחי פעילות",
    "Send activity emails" : "שליחת הודעות פעילות בדוא״ל",
    "Default settings" : "הגדרות ברירת מחדל",
    "Configure the default activity settings for new users." : "הגדרת הגדרות הפעילות כבררת מחדל למשתמשים חדשים",
    "List your own actions in the stream" : "הצגת הפעולות שלך בהזנה",
    "Notify about your own actions via email" : "דיווח על האירועים שלך על בסיס דואר אלקטרוני",
    "You need to set up your email address before you can receive notification emails." : "יש להגדיר כתובת דואר אלקטרוני לפני שניתן יהיה לקבל דיווחים.",
    "Send emails:" : "שליחת הודעות דואר אלקטרוני:",
    "As soon as possible" : "מהר ככל האפשר",
    "Hourly" : "שעתי",
    "Daily" : "יומי",
    "Weekly" : "שבועי",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "נא לבחור עבור אילו מהפעילויות ברצונך לקבל התרעות בדוא״ל ואילו תופענה בתזרים הפעילויות של היישומון.",
    "Choose which activities you want to see in your stream." : "נא לבחור אילו פעילויות יופיעו בתזרים שלך.",
    "Settings" : "הגדרות",
    "Enable RSS feed" : "לאפשר הזנת RSS",
    "RSS feed" : "ערוץ RSS",
    "No more events to load" : "אין אירועים נוספים לטעינה",
    "Files" : "קבצים",
    "Activity notification" : "דיווח פעילות"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/he.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "פעילות",
    "An error occurred while loading activities" : "אירעה שגיאה בעת טעינת הפעילויות",
    "No activity yet" : "אין עדיין פעילויות",
    "Load more activities" : "טעינת פעילויות נוספות",
    "Copied!" : "הועתק!",
    "Not supported!" : "לא נתמך!",
    "Press ⌘-C to copy." : "יש ללחוץ על ‎⌘+C כדי להעתיק.",
    "Press Ctrl-C to copy." : "יש ללחוץ על Ctrl+C כדי להעתיק.",
    "{name} (invisible)" : "{name} (בלתי נראה)",
    "{name} (restricted)" : "{name} (מוגבל)",
    "in {path}" : "ב{path}",
    "This stream will show events like additions, changes & shares" : "הזרמת מידע זו מראה אירועים כגון תוספות, שינויים ושיתופים",
    "There are no events for this filter" : "אין אירועים לסינון זה",
    "Today" : "היום",
    "Yesterday" : "אתמול",
    "Open file" : "פתיחת קובץ",
    "Personal activity feed for %s" : "הזנת פעילות עצמית עבור %s",
    "Your feed URL is invalid" : "כתובת ההזנה שגויה",
    "Your settings have been updated." : "ההגדרות שלך עודכנו",
    "Settings have been updated." : "ההגדרות עודכנו",
    "All activities" : "כל הפעילויות",
    "By others" : "על ידי אחרים",
    "By you" : "על ידך",
    "Activity notification for %s" : "התרעת פעילות עבור %s",
    "Hello %s" : "שלום %s",
    "Hello %s," : "שלום %s,",
    "There was some activity at %s" : "הייתה פעילות ב%s",
    "_and %n more _::_and %n more _" : ["ו־%n נוסף","ו־%n נוספים","ו־%n נוספים","ו־%n נוספים"],
    "Mail" : "דואר",
    "Stream" : "הזרמת מידע",
    "This application enables users to view actions related to their files in Nextcloud." : "יישומון זה מאפשר למשתמשים לצפות בפעולות שקשורות לקבצים שלהם ב־Nextcloud.",
    "Activity feed" : "דיווחי פעילות",
    "Send activity emails" : "שליחת הודעות פעילות בדוא״ל",
    "Default settings" : "הגדרות ברירת מחדל",
    "Configure the default activity settings for new users." : "הגדרת הגדרות הפעילות כבררת מחדל למשתמשים חדשים",
    "List your own actions in the stream" : "הצגת הפעולות שלך בהזנה",
    "Notify about your own actions via email" : "דיווח על האירועים שלך על בסיס דואר אלקטרוני",
    "You need to set up your email address before you can receive notification emails." : "יש להגדיר כתובת דואר אלקטרוני לפני שניתן יהיה לקבל דיווחים.",
    "Send emails:" : "שליחת הודעות דואר אלקטרוני:",
    "As soon as possible" : "מהר ככל האפשר",
    "Hourly" : "שעתי",
    "Daily" : "יומי",
    "Weekly" : "שבועי",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "נא לבחור עבור אילו מהפעילויות ברצונך לקבל התרעות בדוא״ל ואילו תופענה בתזרים הפעילויות של היישומון.",
    "Choose which activities you want to see in your stream." : "נא לבחור אילו פעילויות יופיעו בתזרים שלך.",
    "Settings" : "הגדרות",
    "Enable RSS feed" : "לאפשר הזנת RSS",
    "RSS feed" : "ערוץ RSS",
    "No more events to load" : "אין אירועים נוספים לטעינה",
    "Activities" : "פעילויות",
    "Home" : "בית",
    "\"remote user\"" : "\"משתמש מרוחק\"",
    "Activity notification" : "דיווח פעילות",
    ", " : ",",
    "%s and %s" : "%s ו- %s",
    "Files" : "קבצים"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
